@@ -1,7 +1,8 @@
 """Loguru library wrapper"""
 from typing import Any, Dict, Optional, Union
+import loguru
 
-from ..helpers.singletons import logcounter, logger
+from ..helpers.singletons import logcounter
 from ..constants.config import LogLevels
 from ..helpers.formats import (
     format_log_data,
@@ -16,12 +17,21 @@ class Loguru(LoggerInterface):
     Loguru library wrapper that inherits the LoggerInterface self variables and methods.
 
     This only support the 'log' and 'async_log' methods.
+
+    - self.logger: loguru.Logger = this is the Loguru library logger instance.
+
+    - self.logger.add("logs/logfile.log") = this auto creates the log folder and logfile.log inside it.
+                                            auto creation happens when the logger is initialized,
+                                            or when unit tests are run.
     """
 
     def __init__(self, **kwargs) -> None:
         """Initialize LoggerInterface, self variables and loguru library."""
         super().__init__(**kwargs)
 
+        self.logger: loguru.Logger = loguru.logger
+        self.logger.add("logs/logfile.log")
+
     def log(
         self,
         level: str,
@@ -45,22 +55,22 @@ class Loguru(LoggerInterface):
             _reduce_stack_level,
         )
         if _level == LogLevels.INFO.value:
-            logger.info(data)
+            self.logger.info(data)
         elif _level == LogLevels.DEBUG.value:
-            logger.debug(data)
+            self.logger.debug(data)
         elif _level == LogLevels.WARNING.value:
-            logger.warning(data)
+            self.logger.warning(data)
         elif _level == LogLevels.ERROR.value:
-            logger.error(data)
+            self.logger.error(data)
         elif _level == LogLevels.CRITICAL.value:
-            logger.critical(data)
+            self.logger.critical(data)
         elif _level == LogLevels.EXCEPTION.value:
-            logger.exception(data)
+            self.logger.exception(data)
         else:
             check_log_level_value(level)
 
         logcounter.increment()
-        logger.info(f"Total logs count: {logcounter.counter}")
+        self.logger.info(f"Total logs count: {logcounter.counter}")
 
     async def async_log(
         self,
